@@ -1,22 +1,10 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Rafael Fernández López <ereslibre@kde.org>
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2009 Shaun Reich <shaun.reich@kdemail.net>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Shaun Reich <shaun.reich@kdemail.net>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KWIDGETJOBTRACKER_P_H
@@ -25,32 +13,33 @@
 #include "kabstractwidgetjobtracker_p.h"
 #include "kwidgetjobtracker.h"
 
+#include <QCheckBox>
+#include <QDebug>
 #include <QElapsedTimer>
 #include <QEventLoopLocker>
-#include <QWidget>
 #include <QMap>
 #include <QQueue>
-#include <QCheckBox>
 #include <QUrl>
-#include <QDebug>
+#include <QWidget>
 
 class QPushButton;
 class KSqueezedTextLabel;
 class QLabel;
 class QProgressBar;
 
-class Q_DECL_HIDDEN KWidgetJobTracker::Private
-    : public KAbstractWidgetJobTracker::Private
+class KWidgetJobTrackerPrivate : public KAbstractWidgetJobTrackerPrivate
 {
+    Q_DECLARE_PUBLIC(KWidgetJobTracker)
+
 public:
-    Private(QWidget *parent, KWidgetJobTracker *tracker)
-        : KAbstractWidgetJobTracker::Private(tracker)
+    KWidgetJobTrackerPrivate(QWidget *parent, KWidgetJobTracker *q)
+        : KAbstractWidgetJobTrackerPrivate(q)
         , parent(parent)
         , eventLoopLocker(nullptr)
     {
     }
 
-    virtual ~Private()
+    ~KWidgetJobTrackerPrivate() override
     {
         delete eventLoopLocker;
     }
@@ -70,19 +59,41 @@ public:
     QQueue<KJob *> progressWidgetsToBeShown;
 };
 
-class KWidgetJobTracker::Private::ProgressWidget
-    : public QWidget
+class KWidgetJobTrackerPrivate::ProgressWidget : public QWidget
 {
     Q_OBJECT
 
 public:
     ProgressWidget(KJob *job, KWidgetJobTracker *object, QWidget *parent)
-        : QWidget(parent), tracker(object), job(job), totalSize(0), totalFiles(0), totalDirs(0),
-          processedSize(0), processedDirs(0), processedFiles(0), totalSizeKnown(false),
-          stopOnClose(true), jobRegistered(false), cancelClose(nullptr), openFile(nullptr),
-          openLocation(nullptr), keepOpenCheck(nullptr), pauseButton(nullptr), sourceEdit(nullptr),
-          destEdit(nullptr), progressLabel(nullptr), destInvite(nullptr), speedLabel(nullptr), sizeLabel(nullptr),
-          resumeLabel(nullptr), progressBar(nullptr), suspendedProperty(false), refCount(1)
+        : QWidget(parent)
+        , tracker(object)
+        , job(job)
+        , totalSize(0)
+        , totalFiles(0)
+        , totalDirs(0)
+        , totalItems(0)
+        , processedSize(0)
+        , processedDirs(0)
+        , processedFiles(0)
+        , processedItems(0)
+        , totalSizeKnown(false)
+        , stopOnClose(true)
+        , jobRegistered(false)
+        , cancelClose(nullptr)
+        , openFile(nullptr)
+        , openLocation(nullptr)
+        , keepOpenCheck(nullptr)
+        , pauseButton(nullptr)
+        , sourceEdit(nullptr)
+        , destEdit(nullptr)
+        , progressLabel(nullptr)
+        , destInvite(nullptr)
+        , speedLabel(nullptr)
+        , sizeLabel(nullptr)
+        , resumeLabel(nullptr)
+        , progressBar(nullptr)
+        , suspendedProperty(false)
+        , refCount(1)
     {
         if (!parent) {
             setWindowFlags(windowFlags() | Qt::Dialog);
@@ -93,8 +104,8 @@ public:
 
     ~ProgressWidget()
     {
-        delete tracker->d->eventLoopLocker;
-        tracker->d->eventLoopLocker = nullptr;
+        delete tracker->d_func()->eventLoopLocker;
+        tracker->d_func()->eventLoopLocker = nullptr;
     }
 
     KWidgetJobTracker *const tracker;
@@ -103,9 +114,11 @@ public:
     qulonglong totalSize;
     qulonglong totalFiles;
     qulonglong totalDirs;
+    qulonglong totalItems;
     qulonglong processedSize;
     qulonglong processedDirs;
     qulonglong processedFiles;
+    qulonglong processedItems;
 
     bool totalSizeKnown;
     bool stopOnClose;
@@ -115,8 +128,8 @@ public:
     QPushButton *cancelClose;
     QPushButton *openFile;
     QPushButton *openLocation;
-    QCheckBox   *keepOpenCheck;
-    QUrl        location;
+    QCheckBox *keepOpenCheck;
+    QUrl location;
     QElapsedTimer startTime;
     QPushButton *pauseButton;
     KSqueezedTextLabel *sourceEdit;
@@ -147,9 +160,7 @@ public:
 
 public Q_SLOTS:
     virtual void infoMessage(const QString &plain, const QString &rich);
-    virtual void description(const QString &title,
-                             const QPair<QString, QString> &field1,
-                             const QPair<QString, QString> &field2);
+    virtual void description(const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2);
     virtual void totalAmount(KJob::Unit unit, qulonglong amount);
     virtual void processedAmount(KJob::Unit unit, qulonglong amount);
     virtual void percent(unsigned long percent);
@@ -158,7 +169,7 @@ public Q_SLOTS:
     virtual void suspended();
     virtual void resumed();
 
-    //TODO: Misses canResume()
+    // TODO: Misses canResume()
 
 protected:
     void closeEvent(QCloseEvent *event) override;
@@ -172,7 +183,7 @@ private Q_SLOTS:
     void arrowClicked();
 };
 
-void KWidgetJobTracker::Private::setStopOnClose(KJob *job, bool stopOnClose)
+void KWidgetJobTrackerPrivate::setStopOnClose(KJob *job, bool stopOnClose)
 {
     if (!progressWidget.contains(job)) {
         return;
@@ -180,7 +191,7 @@ void KWidgetJobTracker::Private::setStopOnClose(KJob *job, bool stopOnClose)
     progressWidget[job]->stopOnClose = stopOnClose;
 }
 
-bool KWidgetJobTracker::Private::stopOnClose(KJob *job) const
+bool KWidgetJobTrackerPrivate::stopOnClose(KJob *job) const
 {
     if (!progressWidget.contains(job)) {
         qWarning() << "no widget found for job" << job;
@@ -189,7 +200,7 @@ bool KWidgetJobTracker::Private::stopOnClose(KJob *job) const
     return progressWidget[job]->stopOnClose;
 }
 
-void KWidgetJobTracker::Private::setAutoDelete(KJob *job, bool autoDelete)
+void KWidgetJobTrackerPrivate::setAutoDelete(KJob *job, bool autoDelete)
 {
     if (!progressWidget.contains(job)) {
         return;
@@ -197,7 +208,7 @@ void KWidgetJobTracker::Private::setAutoDelete(KJob *job, bool autoDelete)
     progressWidget[job]->setAttribute(Qt::WA_DeleteOnClose, autoDelete);
 }
 
-bool KWidgetJobTracker::Private::autoDelete(KJob *job) const
+bool KWidgetJobTrackerPrivate::autoDelete(KJob *job) const
 {
     if (!progressWidget.contains(job)) {
         qWarning() << "no widget found for job" << job;
